@@ -23,6 +23,10 @@ schema_properties.update(**base_schema_properties)
 
 class UpdateServiceByWebhooks(EntryPoint):
     """利用webhook更新已经存在的service."""
+    default_config_file_paths = [
+        "./update_service_by_webhooks_config.json"
+    ]
+    argparse_noflag = "tokens"
     schema = {
         "$schema": "http://json-schema.org/draft-07/schema#",
         "type": "object",
@@ -42,7 +46,7 @@ class UpdateServiceByWebhooks(EntryPoint):
             rq.mount('https://', HTTPAdapter(max_retries=Retry(total=int(retry_max_times), backoff_factor=retry_interval_backoff_factor, method_whitelist=frozenset(['GET', 'POST', 'PUT']))))
         log.initialize_for_app(app_name="UpdateStack", log_level=log_level)
         for token in tokens:
-            res = rq.post(f"{base_url}/webhooks/{token}")
+            res = rq.post(f"{base_url}/api/webhooks/{token}")
             if res.status_code >= 300 or res.status_code <= 199:
                 log.error("update service query get error", status_code=res.status_code)
             else:
